@@ -4,7 +4,7 @@ import operator
 import requests
 
 from . import settings
-from .utils import Utils, StatusDict
+from .utils import Utils, StatusDict, colors
 
 
 class SpigetAPI:
@@ -132,12 +132,13 @@ class SpigetAPI:
         latest_version: int = plugin.get("versions")[0].get("id")
 
         if local_version >= latest_version:
-            return StatusDict(
-                True, f"You have the latest version of {plugin.get('name')}"
-            )
+            return StatusDict(False)
         else:
             self.download_plugin(plugin, filename)
-            return StatusDict(True, f"Updated {plugin.get('name')} to latest version")
+            return StatusDict(
+                True,
+                f"Updated {plugin.get('name')} to latest version",
+            )
 
     def get_author(self, author_id: int) -> dict:
         """
