@@ -10,6 +10,13 @@ from colorama import init as init_colorama
 
 from . import settings
 
+colors = {
+    "error": Fore.RED,
+    "warning": Fore.YELLOW,
+    "status": Fore.LIGHTWHITE_EX,
+    "success": Fore.GREEN,
+}
+
 
 class StatusDict(dict):
     """
@@ -20,20 +27,13 @@ class StatusDict(dict):
         }
     """
 
-    def __init__(self, status, message=""):
-        super().__init__()
-        self["status"] = status
-        self["message"] = message
+    def __init__(self, status: bool, message: str = ""):
+        super().__init__(status=status, message=message)
 
 
 class Utils:
     init_colorama()
 
-    @staticmethod
-    def sanitise_input(text: str) -> str:
-        # TODO: Is this needed?
-        return text
-
     @staticmethod
     def sanitise_api_plugin(plugin: dict) -> dict:
         """
@@ -52,7 +52,7 @@ class Utils:
         split_name = re.split("[-|/!\\[\\]<>~•·×✘]", plugin.get("name"))
         name = ""
         # If a split doesn't contain any safe characters we can assume it is fluff
-        # this should remove segments like (1.13-1.17) at the beginning of names
+        # this should remove splits like (1.13-1.17) at the beginning of names
         for split in split_name:
             for char in split:
                 if char in safe_chars:
@@ -75,7 +75,6 @@ class Utils:
 
     @staticmethod
     def create_jar_name(text: str) -> str:
-        text = Utils.sanitise_input(text)
         return text.translate(str.maketrans("", "", string.whitespace)) + ".jar"
 
     @staticmethod
@@ -85,33 +84,23 @@ class Utils:
         return jar_name
 
     @staticmethod
-    def status(text) -> None:
-        print(Fore.LIGHTWHITE_EX + text + Fore.RESET)
+    def format_text(text: str, ansi_color: str, print_text=True) -> str or None:
+        formatted_text = ansi_color + text + Fore.RESET
+        if print_text:
+            print(formatted_text)
+        else:
+            return formatted_text
 
-    @staticmethod
-    def status_good(text) -> None:
-        print(Fore.GREEN + text + Fore.RESET)
-
-    @staticmethod
-    def error(text, fatal=True) -> None:
-        print(Fore.RED + text + Fore.RESET)
-        if fatal:
-            sys.exit(1)
-
-    @staticmethod
-    def warning(text) -> None:
-        print(Fore.YELLOW + text + Fore.RESET)
-
-    @staticmethod
-    def prompt(text) -> str:
+    @classmethod
+    def prompt(cls, text) -> str:
         try:
-            return input(Fore.CYAN + text + ": " + Fore.RESET)
+            return input(cls.format_text(text + ": ", colors["status"], print_text=False))
         except KeyboardInterrupt:
             sys.exit(1)
 
     @staticmethod
     def separator() -> None:
-        sep_char = "-"
+        sep_char = "="
         print(Fore.WHITE + (sep_char * 15) + Fore.RESET)
 
     # noinspection PyBroadException
@@ -129,21 +118,21 @@ class Utils:
             with zipfile.ZipFile(filename, "a") as jar:
                 jar.writestr(settings.METADATA_FILENAME, metadata)
         except:
-            Utils.error("Could not write metadata file due to an unknown error!")
+            Utils.format_text(
+                "Could not write metadata file due to an unknown error", colors["error"]
+            )
 
     # noinspection PyBroadException
     @staticmethod
-    def load_metadata_file(filename: str) -> dict:
+    def load_metadata_file(filename: str) -> dict or None:
         try:
             with zipfile.ZipFile(filename) as jar:
                 metadata: str = jar.read(settings.METADATA_FILENAME).decode("UTF-8")
                 metadata: dict = json.loads(metadata)
                 return metadata
 
-        except (FileNotFoundError, KeyError):
-            return {}
-        except:
-            Utils.error(f"Could not read metadata file due to unknown error.")
+        except (FileNotFoundError, KeyError, zipfile.BadZipfile):
+            return None
 
     @staticmethod
     def split_title_case(text: str) -> str:
